summaryrefslogtreecommitdiff
path: root/libavcodec/lagarithrac.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavcodec/lagarithrac.c')
-rw-r--r--libavcodec/lagarithrac.c11
1 files changed, 5 insertions, 6 deletions
diff --git a/libavcodec/lagarithrac.c b/libavcodec/lagarithrac.c
index f9e4e5c928..2bc88a92a9 100644
--- a/libavcodec/lagarithrac.c
+++ b/libavcodec/lagarithrac.c
@@ -27,20 +27,19 @@
* @author David Conrad
*/
-#include "get_bits.h"
#include "lagarithrac.h"
-void ff_lag_rac_init(lag_rac *l, GetBitContext *gb, int length)
+void ff_lag_rac_init(lag_rac *l, BitstreamContext *bc, int length)
{
int i, j, left;
/* According to reference decoder "1st byte is garbage",
* however, it gets skipped by the call to align_get_bits()
*/
- align_get_bits(gb);
- left = get_bits_left(gb) >> 3;
+ bitstream_align(bc);
+ left = bitstream_bits_left(bc) >> 3;
l->bytestream_start =
- l->bytestream = gb->buffer + get_bits_count(gb) / 8;
+ l->bytestream = bc->buffer + bitstream_tell(bc) / 8;
l->bytestream_end = l->bytestream_start + FFMIN(length, left);
l->range = 0x80;
@@ -27,20 +27,19 @@
int i, j, left;
/* According to reference decoder "1st byte is garbage",
- * however, it gets skipped by the call to align_get_bits()
+ * however, it gets skipped by the call to bitstream_align()
*/